export declare enum ManifestType {
    Component = "component",
    Resource = "resource",
}
/**
    Rules applied clientside
    Every rule is compared to the current server relative url of the page
*/
export interface ILoadByUrl {
    /**
        For all urls starting with e.g. / - from and down root,
        /site1/page2 etc
    */
    startsWith?: string;
    /**
        Loaded if regEx matches current serverrelative path
    */
    regEx?: string;
}
export declare class LoadByUrlMerger {
    private rules;
    private regExps;
    private startsWith;
    add: (rule: ILoadByUrl) => void;
    getUniqueRules: () => ILoadByUrl[];
}
export interface IManifest {
    /**
        The unique id of the manifest, this will be the id of the resources added.
    */
    resourceId: string;
    manifestType: ManifestType;
}
export interface IManifestDependency {
    resourceId: string;
    extensionId: string;
}
export interface IClientManifest extends IManifest {
    /**
        The id of the extension to which the resource belong
    */
    extensionId: string;
    dependingOnManifests: Array<IManifestDependency>;
}
export interface IClientManifestProvider {
    getClientManifests: (currentExtensionId: string) => Array<IClientManifest>;
    clearState: () => void;
}
export declare class ManifestRegistry {
    private static CurrentManifestPath;
    private static ManifestDependencies;
    private static ClientManifests;
    private static RegisteredManifests;
    private static ClientManifestProviders;
    static setCurrentManifestPath: (manifestPath?: string) => void;
    static getCurrentManifestPath: () => string;
    static getRegisteredManifest: (manifestId: string) => IManifest;
    static addManifestDependency: (manifestId: string, dependentOnManifestId: string, dependentManifestExtensionId?: string) => void;
    static getManifestDependencies: (manifestId: string, currentExtensionId: string) => IManifestDependency[];
    static registerManifest: (manifest: IManifest) => IManifest;
    static registerManifestProvider: (provider: IClientManifestProvider) => void;
    static getClientManifests: (currentExtensionId: string) => IClientManifest[];
    static clearState: () => void;
    private static validateDependencies;
    private static addClientManifest;
}
